Opinions

Supreme Court
Circuit Court
Drug Court
Small Claims
Contact Information
Information
Search
-or-
-or-
Judicial Qualifications Commission
Board of Bar Examiners
Contact Information
Supreme Court
State Court Administration
Circuit Courts
Clerk of Courts
Court Services Offices
Court Reporters
Tribal Courts
Aurora County Courthouse
Beadle County Courthouse
Bennett County Courthouse
Bon Homme County Courthouse
Brookings County Courthouse
Brown County Courthouse
Brule County Courthouse
Butte County Courthouse
Campbell County Courthouse
Charles Mix County Courthouse
Clark County Courthouse
Clay County Courthouse
Codington County Courthouse
Corson County Courthouse
Custer County Courthouse
Davison County Courthouse
Day County Courthouse
Deuel County Courthouse
Dewey County Courthouse
Douglas County Courthouse
Edmunds County Courthouse
Fall River County Courthouse
Faulk County Courthouse
Grant County Courthouse
Gregory County Courthouse
Haakon County Courthouse
Hamlin County Courthouse
Hand County Courthouse
Hanson County Courthouse
Harding County Courthouse
Hughes County Courthouse
Hutchinson County Courthouse
Hyde County Courthouse
Jackson County Courthouse
Jerauld County Courthouse
Jones County Courthouse
Kingsbury County Courthouse
Lake County Courthouse
Lawrence County Courthouse
Lincoln County Courthouse
Lyman County Courthouse
McCook County Courthouse
McPherson County Courthouse
Marshall County Courthouse
Meade County Courthouse
Mellette County Courthouse
Miner County Courthouse
Minnehaha County Courthouse
Moody County Courthouse
Pennington County Courthouse
Perkins County Courthouse
Potter County Courthouse
Roberts County Courthouse
Sanborn County Courthouse
Spink County Courthouse
Stanley County Courthouse
Sully County Courthouse
Tripp County Courthouse
Turner County Courthouse
Union County Courthouse
Walworth County Courthouse
Yankton County Courthouse
Ziebach County Courthouse

Learn About the Courts
Information for...
Odyssey/File and Serve

### Circuit Courts

- First Judicial Circuit
- Second Judicial Circuit
- Third Judicial Circuit
- Fourth Judicial Circuit
- Fifth Judicial Circuit
- Sixth Judicial Circuit
- Seventh Judicial Circuit

### Other Information

- Circuit Boundaries
- Councils and Committees
- Drug and DUI Court
- Guide To Your Courts

- Interpreters
- Judicial Elections Committee
- Jury Orientation
- Kids and the Kourts
- Legal Form Helpline
- Media Coverage
- Org. Chart
- Overview of the Courts
- Project Rural Practice
- Senate Bill 70 Website
- Small Claims
- State of Judiciary Messages
- Structure - UJS
- Veterans Project

- Attorneys
- Educators
- Employees
- Interpreters

- Judges
- Jurors
- Media
- The public

### Odyssey

- Conversion timeline
- Odyssey Courtroom Calendar
- Public Access Computer Instructions
- What is Odyssey?

### File and Serve

- F&S website
- Proposed F&S Timeline
- F&S FAQ
- Rule 13-12
- F&S Filer Training Presentation
- F&S Introduction
- F&S Access and Registration
- F&S Basics and Administration
- F&S Electronic Filing
- F&S Electronic Service

Loading
Self-Help Center
Forms
Publications
Programs & Services
Probation Services

# Supreme Court Opinions

Select an Opinion Year:

Opinion Date | Opinion Title/Link | Opinion Number
--- | --- | ---
07/30/2014 | STATE v. WHISTLER, 2014 S.D. 58 | 58
07/30/2014 | FIRST DAKOTA BANK v. BANCINSURE, 2014 S.D. 57 | 57
07/30/2014 | KREISERS v. FIRST DAKOTA TITLE, 2014 S.D. 56 | 56
07/30/2014 | STATE v. NEKOLITE, 2014 S.D. 55 | 55
07/23/2014 | ESTATE OF RICARD, 2014 S.D. 54 | 54
07/23/2014 | LIEBIG v. KIRCHOFF, 2014 S.D. 53 | 53
07/23/2014 | OCWEN v. ELLIOT, 2014 S.D. 52 | 52
07/23/2014 | SIERS v. WEBER, 2014 S.D. 51 | 51
07/16/2014 | STATE v. SMITH, 2014 S.D. 50 | 50
07/16/2014 | STATE v. MILLER, 2014 S.D. 49 | 49
07/16/2014 | STATE v. BAUER, 2014 S.D. 48 | 48
07/16/2014 | STATE v. ROLFE, 2014 S.D. 47 | 47
07/09/2014 | STATE v. BLAKNEY, 2014 S.D. 46 | 46
07/09/2014 | WICHMAN v. SHABINO, 2014 S.D. 45 | 45
07/09/2014 | TIBBS v. MOODY CNTY., 2014 S.D. 44 | 44
1 | 2 | 3 | 4

Home | Forms | Calendar | News | Records | Opinions | Contact Us
©Copyright 2012 - State of South Dakota

- Child Support Calculator
- Civil Filing Fees and Costs
- Civil Money Judgment System
- Court Appointed Attorney Fees
- Court Opinions
- Court Records
- Criminal Court Costs
- Current Job Announcements
- New! Divorce for the Self-Represented Litigant
- Drug Court
- Juror Orientation Video
- Juror Orientation Video (Closed Captioning)
- Legal Form Helpline

- Parenting Time Forms
- Parenting Time Guidelines
- Petition for Modification of Child Support Obligation
- Protection Order System
- Report of the 2012 South Dakota Commission on Child Support
- Service Providers
- Small Claims Fee Calculator
- Supreme Court Opinions
- Supreme Court Rules
- Useful Links
- Useful Documents
- Where your $$$ goes

- Adoption Reporting
- Child Support Late Fee
- Civil Filing Statements
- Confidential Financial Documents Info
- Confidential Information
- Document Return Request (PDF)
- Document Return Request (fillable Word)
- Domestic Protection Order
- New! Divorce for the Self-Represented Litigant

- Expungement Instruction Sheet
- Legal Form Helpline
- Mediation Application
- Parenting Time
- Pro Se Name Change - Adult
- Pro Se Name Change - Child
- Record Search Request
- Spanish Documents (Los Documentos Españoles)
- Stalking Protection Order

- Annual Reports
- Clerk of Courts History
- Councils and Committees Overview
- Drug Court Study
- Equal Justice Commission Final Report
- Guide to Child Abuse and Neglect Cases
- Judicial Elections Brochure
- Judiciary Message
- Juror Orientation Video
- Media Coverage Brochure

- Parenting Time Guidelines
- Photographic History
- Representing Yourself
- SD Court Reporter Manual
- Study of Cameras in the Courtroom
- Study of Cameras in the Courtroom - Appendix
- Study of Interpreters and Translators
- Term of Court Booklets
- Where your $$$ goes

- Approved Mediators
- Bail Bond Agents
- Court Improvement Program (CIP)
- Chemical Abuse Evaluation Agency List
- Child Custody Evaluators
- Child Support Referees

- Court Interpreters
- Parenting Coordinators
- Process Servers
- Project Rural Practice
- Rural Attorney Recruitment Program
- South Dakota State Bar Association

- About Probation Services
- Court Services Responsibilities

- FY 2013 Supervision Costs
- Systemic Approach to Supervision Presentation